@@ -1,11 +1,14 @@
-import mock
-
 from sentry_sdk import (
     configure_scope,
     get_current_span,
     start_transaction,
 )
 
+try:
+    from unittest import mock  # python 3.3 and above
+except ImportError:
+    import mock  # python < 3.3
+
 
 def test_get_current_span():
     fake_hub = mock.MagicMock()
